@@ -24,6 +24,18 @@ import json
 import warnings
 
 from pypdb.util import http_requests
+from pypdb.clients.fasta import fasta_client
+from pypdb.clients.pdb import pdb_client
+from pypdb.clients.search import search_client
+from pypdb.clients.search.operators import sequence_operators
+
+warnings.simplefilter('always', DeprecationWarning)
+
+
+# New imports needed for the updated API
+from pypdb.clients.search.search_client import perform_search
+from pypdb.clients.search.search_client import ReturnType
+from pypdb.clients.search.operators import text_operators
 
 
 '''
@@ -32,6 +44,7 @@ Functions for searching the RCSB PDB for lists of PDB IDs
 =================
 '''
 
+
 class Query(object):
     """
 
@@ -90,15 +103,13 @@ class Query(object):
     ['3LEZ', '3SGH', '4F47']
 
     """
-
     def __init__(self,
                  search_term,
-                 query_type="text",
+                 query_type="full_text",
                  return_type="entry",
                  scan_params=None):
         """See help(Query) for documentation"""
 
-
         if query_type == "PubmedIdQuery":
             query_type = "text"
             query_subtype = "pmid"
@@ -109,11 +120,16 @@ class Query(object):
             query_type = "text"
             query_subtype = "experiment_type"
             search_term = search_term.upper()
-            if search_term not in ["X-RAY DIFFRACTION", "ELECTRON MICROSCOPY", "SOLID-STATE NMR", "SOLUTION NMR",
-                             "NEUTRON DIFFRACTION", "ELECTRON CRYSTALLOGRAPHY", "POWDER DIFFRACTION",
-                             "FIBER DIFFRACTION", "SOLUTION SCATTERING", "EPR", "FLUORESCENCE TRANSFER",
-                            "INFRARED SPECTROSCOPY", "THEORETICAL MODEL"]:
-                warnings.warn("Experimental type not recognized, search may fail .")
+            if search_term not in [
+                    "X-RAY DIFFRACTION", "ELECTRON MICROSCOPY",
+                    "SOLID-STATE NMR", "SOLUTION NMR", "NEUTRON DIFFRACTION",
+                    "ELECTRON CRYSTALLOGRAPHY", "POWDER DIFFRACTION",
+                    "FIBER DIFFRACTION", "SOLUTION SCATTERING", "EPR",
+                    "FLUORESCENCE TRANSFER", "INFRARED SPECTROSCOPY",
+                    "THEORETICAL MODEL"
+            ]:
+                warnings.warn(
+                    "Experimental type not recognized, search may fail .")
         elif query_type == "AdvancedAuthorQuery":
             query_type = "text"
             query_subtype = "author"
@@ -126,11 +142,12 @@ class Query(object):
         else:
             query_subtype = None
 
-        assert query_type in {"text", "structure", "sequence", "seqmotif", "chemical"
-                             }, "Query type %s not recognized." % query_type
-
-        assert return_type in {"entry", "polymer_entity"}, "Return type %s not supported." % return_type
+        assert query_type in {
+            "full_text", "text", "structure", "sequence", "seqmotif", "chemical"
+        }, "Query type %s not recognized." % query_type
 
+        assert return_type in {"entry", "polymer_entity"
+                               }, "Return type %s not supported." % return_type
 
         self.query_type = query_type
         self.search_term = search_term
@@ -142,16 +159,22 @@ class Query(object):
             query_params["type"] = "terminal"
             query_params["service"] = query_type
 
-            if query_type == "text":
-                query_params['parameters'] = {"value" : search_term}
+            if query_type in ["full_text", "text"]:
+                query_params['parameters'] = {"value": search_term}
 
-            elif query_type=="sequence":
-                query_params['parameters'] = {"target": "pdb_protein_sequence",
-                                              "value" : search_term}
-            elif query_type=="structure":
-                query_params['parameters'] = {"operator": "relaxed_shape_match",
-                                              "value" : {"entry_id" : search_term, "assembly_id": "1"}
-                                             }
+            elif query_type == "sequence":
+                query_params['parameters'] = {
+                    "target": "pdb_protein_sequence",
+                    "value": search_term
+                }
+            elif query_type == "structure":
+                query_params['parameters'] = {
+                    "operator": "relaxed_shape_match",
+                    "value": {
+                        "entry_id": search_term,
+                        "assembly_id": "1"
+                    }
+                }
 
 #             elif query_type=='AdvancedAuthorQuery':
 #                 query_params['description'] = 'Author Name: '+ search_term
@@ -184,50 +207,64 @@ class Query(object):
             if query_subtype:
 
                 if query_subtype == "pmid":
-                    query_params['parameters'] = {"operator" : "in",
-                                                  "negation": False,
-                                                  "value" : [search_term],
-                                                  "attribute": "rcsb_pubmed_container_identifiers.pubmed_id"
-                                                 }
+                    query_params['parameters'] = {
+                        "operator": "in",
+                        "negation": False,
+                        "value": [search_term],
+                        "attribute":
+                        "rcsb_pubmed_container_identifiers.pubmed_id"
+                    }
                 if query_subtype == "taxid":
-                    query_params['parameters'] = {"operator": "exact_match",
-                                                  "negation": False,
-                                                  "value" : str(search_term),
-                                                  "attribute": "rcsb_entity_source_organism.taxonomy_lineage.id"
-                                                 }
+                    query_params['parameters'] = {
+                        "operator":
+                        "exact_match",
+                        "negation":
+                        False,
+                        "value":
+                        str(search_term),
+                        "attribute":
+                        "rcsb_entity_source_organism.taxonomy_lineage.id"
+                    }
                 if query_subtype == "experiment_type":
-                    query_params['parameters'] = {"operator": "exact_match",
-                                                  "negation": False,
-                                                  "value" : str(search_term),
-                                                  "attribute": "exptl.method"
-                                                 }
+                    query_params['parameters'] = {
+                        "operator": "exact_match",
+                        "negation": False,
+                        "value": str(search_term),
+                        "attribute": "exptl.method"
+                    }
                 if query_subtype == "author":
-                    query_params['parameters'] = {"operator": "exact_match",
-                                                  "negation": False,
-                                                  "value" : str(search_term),
-                                                  "attribute": "rcsb_primary_citation.rcsb_authors"
-                                                 }
+                    query_params['parameters'] = {
+                        "operator": "exact_match",
+                        "negation": False,
+                        "value": str(search_term),
+                        "attribute": "rcsb_primary_citation.rcsb_authors"
+                    }
                 if query_subtype == "organism":
-                    query_params['parameters'] = {"operator": "contains_words",
-                                                  "negation": False,
-                                                  "value" : str(search_term),
-                                                  "attribute": "rcsb_entity_source_organism.taxonomy_lineage.name"
-                                                 }
+                    query_params['parameters'] = {
+                        "operator":
+                        "contains_words",
+                        "negation":
+                        False,
+                        "value":
+                        str(search_term),
+                        "attribute":
+                        "rcsb_entity_source_organism.taxonomy_lineage.name"
+                    }
                 if query_subtype == "pfam":
-                    query_params['parameters'] = {"operator": "exact_match",
-                                                  "negation": False,
-                                                  "value" : str(search_term),
-                                                  "attribute": "rcsb_polymer_entity_annotation.annotation_id"
-                                                 }
-
-
+                    query_params['parameters'] = {
+                        "operator": "exact_match",
+                        "negation": False,
+                        "value": str(search_term),
+                        "attribute":
+                        "rcsb_polymer_entity_annotation.annotation_id"
+                    }
 
             self.scan_params = dict()
             self.scan_params["query"] = query_params
             self.scan_params["return_type"] = return_type
 
             if return_type == "entry":
-                self.scan_params["request_options"] = {"return_all_hits" : True}
+                self.scan_params["request_options"] = {"return_all_hits": True}
 
         else:
             self.scan_params = scan_params
@@ -247,19 +284,21 @@ class Query(object):
         """
 
         query_text = json.dumps(self.scan_params, indent=4)
-        response = http_requests.request_limited(self.url, rtype="POST",
-         data=query_text)
+        response = http_requests.request_limited(self.url,
+                                                 rtype="POST",
+                                                 data=query_text)
 
-        if response.status_code == 200:
-            pass
-        else:
+        if response is None or response.status_code != 200:
             warnings.warn("Retrieval failed, returning None")
             return None
 
         response_val = json.loads(response.text)
 
         if self.return_type == "entry":
-            idlist = walk_nested_dict(response_val, "identifier", maxdepth=25, outputs=[])
+            idlist = walk_nested_dict(response_val,
+                                      "identifier",
+                                      maxdepth=25,
+                                      outputs=[])
             return idlist
         else:
             return response_val
@@ -279,7 +318,6 @@ class Query(object):
 #         A dictionary of query attributes to use for
 #         the search of the PDB
 
-
 #     Returns
 #     -------
 
@@ -296,7 +334,6 @@ class Query(object):
 #     'keywords': 'actin',
 #     'queryType': 'AdvancedKeywordQuery'}}
 
-
 #     >>> search_dict = make_query('actin network')
 #     >>> found_pdbs = do_search(search_dict)
 #     >>> print(found_pdbs)
@@ -310,7 +347,6 @@ class Query(object):
 #     q = Query('search_term', 'HoldingsQuery', scan_params=scan_params)
 #     return q.search()
 
-
 # def do_protsym_search(point_group, min_rmsd=0.0, max_rmsd=7.0):
 #     '''Performs a protein symmetry search of the PDB
 
@@ -359,7 +395,6 @@ class Query(object):
 #     idlist =  do_search(scan_params)
 #     return idlist
 
-
 # def get_all():
 #     """Return a list of all PDB entries currently in the RCSB Protein Data Bank
 
@@ -396,13 +431,13 @@ class Query(object):
 #         out.append(item[-5:-1])
 
 #     return out
-
 '''
 =================
 Functions for looking up information given PDB ID
 =================
 '''
 
+
 def get_info(pdb_id, url_root='https://data.rcsb.org/rest/v1/core/entry/'):
     '''Look up all information about a given PDB ID
 
@@ -422,190 +457,50 @@ def get_info(pdb_id, url_root='https://data.rcsb.org/rest/v1/core/entry/'):
         An ordered dictionary object corresponding to entry information
 
     '''
-    pdb_id = pdb_id.replace(":", "/") # replace old entry identifier
+    pdb_id = pdb_id.replace(":", "/")  # replace old entry identifier
     url = url_root + pdb_id
     response = http_requests.request_limited(url)
 
-    if response.status_code == 200:
-        pass
-    else:
+    if response is None or response.status_code != 200:
         warnings.warn("Retrieval failed, returning None")
         return None
 
-    result  = str(response.text)
+    result = str(response.text)
 
     out = json.loads(result)
 
     return out
 
-get_all_info = get_info # Alias
-describe_pdb = get_info # Alias for now; eve tually make this point to the Graph search https://data.rcsb.org/migration-guide.html#pdb-file-description
-get_entity_info = get_info # Alias
 
-def get_pdb_file(pdb_id, filetype='pdb', compression=False):
-    '''Get the full PDB file associated with a PDB_ID
+get_all_info = get_info  # Alias
+describe_pdb = get_info  # Alias for now; eventually make this point to the Graph search https://data.rcsb.org/migration-guide.html#pdb-file-description
+get_entity_info = get_info  # Alias
 
-    Parameters
-    ----------
 
-    pdb_id : string
-        A 4 character string giving a pdb entry of interest
+def get_pdb_file(pdb_id: str, filetype='pdb', compression=False):
+    """Deprecated wrapper for fetching PDB files from RCSB Database.
 
-    filetype: string
-        The file type.
-        'pdb' is the older file format,
-        'cif' is the newer replacement.
-        'xml' an also be obtained and parsed using the various xml tools included in PyPDB
-        'structfact' retrieves structure factors (only available for certain PDB entries)
+    For new uses, please use `pypdb/clients/pdb/pdb_client.py`
+    """
 
-    compression : bool
-        Retrieve a compressed (gz) version of the file
+    warnings.warn(
+        "The `get_pdb_file` function within pypdb.py is deprecated."
+        "See `pypdb/clients/pdb/pdb_client.py` for a near-identical "
+        "function to use", DeprecationWarning)
 
-    Returns
-    -------
-
-    result : string
-        The string representing the full PDB file in the given format
-
-    Examples
-    --------
-    >>> pdb_file = get_pdb_file('4lza', filetype='cif', compression=True)
-    >>> print(pdb_file[:200])
-    data_4LZA
-    #
-    _entry.id   4LZA
-    #
-    _audit_conform.dict_name       mmcif_pdbx.dic
-    _audit_conform.dict_version    4.032
-    _audit_conform.dict_location   http://mmcif.pdb.org/dictionaries/ascii/mmcif_pdbx
-
-    '''
-
-    full_url = "https://files.rcsb.org/download/"
-
-    full_url += pdb_id
-
-    if (filetype == 'structfact'):
-        full_url += "-sf.cif"
+    if filetype is 'pdb':
+        filetype_enum = pdb_client.PDBFileType.PDB
+    elif filetype is 'cif':
+        filetype_enum = pdb_client.PDBFileType.CIF
+    elif filetype is 'xml':
+        filetype_enum = pdb_client.PDBFileType.XML
+    elif filetype is 'structfact':
+        filetype_enum = pdb_client.PDBFileType.STRUCTFACT
     else:
-        full_url += "." + filetype
+        warnings.warn(
+            "Filetype specified to `get_pdb_file` appears to be invalid")
 
-    if compression:
-        full_url += ".gz"
-    else:
-        pass
-
-    #response = requests.get(full_url)
-    response = http_requests.request_limited(full_url)
-
-    if response.status_code == 200:
-        pass
-    else:
-        warnings.warn("Retrieval failed, returning None")
-        return None
-
-    if compression:
-        result  = response.content
-    else:
-        result = response.text
-
-    ## return raw file only
-    # if compression:
-    #     result = result.decode('utf-8')
-    # else:
-    #     pass
-
-    return result
-
-# def get_raw_blast(pdb_id, output_form='HTML', chain_id='A'):
-#     '''Look up full BLAST page for a given PDB ID
-
-#     get_blast() uses this function internally
-
-#     Parameters
-#     ----------
-
-#     pdb_id : string
-#         A 4 character string giving a pdb entry of interest
-
-#     chain_id : string
-#         A single character designating the chain ID of interest
-
-
-#     output_form : string
-#         TXT, HTML, or XML formatting of the outputs
-
-#     Returns
-#     -------
-
-#     out : OrderedDict
-#         An ordered dictionary object corresponding to bare xml
-
-#     '''
-
-#     url_root = 'http://www.rcsb.org/pdb/rest/getBlastPDB2?structureId='
-#     url = url_root + pdb_id + '&chainId='+ chain_id +'&outputFormat=' + output_form
-
-#     #response = requests.get(url)
-#     response = http_requests.request_limited(url)
-
-
-#     if response.status_code == 200:
-#         pass
-#     else:
-#         warnings.warn("Retrieval failed, returning None")
-#         return None
-
-#     result  = response.text
-
-#     return result
-
-
-# def parse_blast(blast_string):
-#     '''Clean up HTML BLAST results
-
-#     This function requires BeautifulSoup and the re module
-#     It goes throught the complicated output returned by the BLAST
-#     search and provides a list of matches, as well as the raw
-#     text file showing the alignments for each of the matches.
-
-#     This function works best with HTML formatted Inputs
-#     ------
-
-#     get_blast() uses this function internally
-
-#     Parameters
-#     ----------
-
-#     blast_string : str
-#         A complete webpage of standard BLAST results
-
-#     Returns
-#     -------
-
-#     out : 2-tuple
-#         A tuple consisting of a list of PDB matches, and a list
-#         of their alignment text files (unformatted)
-
-
-#     '''
-
-#     soup = BeautifulSoup(str(blast_string), "html.parser")
-
-#     all_blasts = list()
-#     all_blast_ids = list()
-
-#     pattern = '></a>....:'
-#     prog = re.compile(pattern)
-
-#     for item in soup.find_all('pre'):
-#         if len(item.find_all('a'))==1:
-#             all_blasts.append(item)
-#             blast_id = re.findall(pattern, str(item) )[0][-5:-1]
-#             all_blast_ids.append(blast_id)
-
-#     out = (all_blast_ids, all_blasts)
-#     return out
+    return pdb_client.get_pdb_file(pdb_id, filetype_enum, compression)
 
 
 # https://data.rcsb.org/migration-guide.html#chem-comp-description
@@ -656,7 +551,6 @@ def get_pdb_file(pdb_id, filetype='pdb', compression=False):
 #     out : dict
 #         A dictionary containing a list of ligands associated with the entry
 
-
 #     Examples
 #     --------
 #     >>> ligand_dict = get_ligands('100D')
@@ -757,51 +651,68 @@ def get_pdb_file(pdb_id, filetype='pdb', compression=False):
 #     out = to_dict(out)
 #     return remove_at_sign(out['sequenceCluster'])
 
-# def get_blast(pdb_id, chain_id='A'):
-#     """
-#     Return BLAST search results for a given PDB ID
-#     The key of the output dict())that outputs the full search results is
-#     'BlastOutput_iterations'
 
-#     To get a list of just the results without the metadata of the search use:
-#     hits = full_results['BlastOutput_iterations']['Iteration']['Iteration_hits']['Hit']
+def get_blast(pdb_id, chain_id='A', identity_cutoff=0.99):
+    """
+    ---
+    WARNING: this function is deprecated and slated to be deleted due to RCSB
+    API changes.
 
-#     Parameters
-#     ----------
-#     pdb_id : string
-#         A 4 character string giving a pdb entry of interest
+    See `pypdb/clients/search/EXAMPLES.md` for examples to use a
+    `SequenceOperator` search to similar effect
+    ---
 
-#     chain_id : string
-#         A single character designating the chain ID of interest
+    Return BLAST search results for a given PDB ID.
+
+    Parameters
+    ----------
+    pdb_id : string
+        A 4 character string giving a pdb entry of interest
+
+    chain_id : string
+        A single character designating the chain ID of interest
+    identity_cutoff: float
+        Identity % at which to cut off results.
 
 
-#     Returns
-#     -------
+    Returns
+    -------
 
-#     out : dict()
-#         A nested dict() consisting of the BLAST search results and all associated metadata
-#         If you just want the hits, look under four levels of keys:
-#         results['BlastOutput_iterations']['Iteration']['Iteration_hits']['Hit']
+    out : List of PDB IDs that match the given search.
 
-#     Examples
-#     --------
+    Examples
+    --------
 
-#     >>> blast_results = get_blast('2F5N', chain_id='A')
-#     >>> just_hits = blast_results['BlastOutput_iterations']['Iteration']['Iteration_hits']['Hit']
-#     >>> print(just_hits[50]['Hit_hsps']['Hsp']['Hsp_hseq'])
-#     PELPEVETVRRELEKRIVGQKIISIEATYPRMVL--TGFEQLKKELTGKTIQGISRRGKYLIFEIGDDFRLISHLRMEGKYRLATLDAPREKHDHL
-#     TMKFADG-QLIYADVRKFGTWELISTDQVLPYFLKKKIGPEPTYEDFDEKLFREKLRKSTKKIKPYLLEQTLVAGLGNIYVDEVLWLAKIHPEKET
-#     NQLIESSIHLLHDSIIEILQKAIKLGGSSIRTY-SALGSTGKMQNELQVYGKTGEKCSRCGAEIQKIKVAGRGTHFCPVCQQ
+    >>> blast_results = get_blast('2F5N', chain_id='A')
+    >>> print(blast_results[50])
+    PELPEVETVRRELEKRIVGQKIISIEATYPRMVL--TGFEQLKKELTGKTIQGISRRGKYLIFEIGDDFRLISHLRMEGKYRLATLDAPREKHDHL
+    TMKFADG-QLIYADVRKFGTWELISTDQVLPYFLKKKIGPEPTYEDFDEKLFREKLRKSTKKIKPYLLEQTLVAGLGNIYVDEVLWLAKIHPEKET
+    NQLIESSIHLLHDSIIEILQKAIKLGGSSIRTY-SALGSTGKMQNELQVYGKTGEKCSRCGAEIQKIKVAGRGTHFCPVCQQ
+    """
 
+    warnings.warn(
+        "The `get_blast` function is slated for deprecation."
+        "See `pypdb/clients/search/EXAMPLES.md` for examples to use a"
+        "`SequenceOperator` search to similar effect", DeprecationWarning)
 
-#     """
+    fasta_entries = fasta_client.get_fasta_from_rcsb_entry(pdb_id)
+    valid_sequences = [
+        fasta_entry.sequence for fasta_entry in fasta_entries
+        if chain_id in fasta_entry.chains
+    ]
 
-#     raw_results = get_raw_blast(pdb_id, output_form='XML', chain_id=chain_id)
+    matches_any_sequence_in_chain_query = search_client.QueryGroup(
+        logical_operator=search_client.LogicalOperator.OR, queries=[])
+    for valid_sequence in valid_sequences:
+        matches_any_sequence_in_chain_query.queries.append(
+            sequence_operators.SequenceOperator(
+                sequence=valid_sequence,
+                identity_cutoff=identity_cutoff,
+                evalue_cutoff=1000))
 
-#     out = xmltodict.parse(raw_results, process_namespaces=True)
-#     out = to_dict(out)
-#     out = out['BlastOutput']
-#     return out
+    return search_client.perform_search_with_graph(
+        query_object=matches_any_sequence_in_chain_query,
+        return_raw_json_dict=True)
 
 
 # def get_pfam(pdb_id):
@@ -835,7 +746,6 @@ def get_pdb_file(pdb_id, filetype='pdb', compression=False):
 #         return dict()
 #     return remove_at_sign(out['hmmer3'])
 
-
 # def get_clusters(pdb_id):
 #     """Return cluster related web services of given PDB_ID
 
@@ -864,7 +774,6 @@ def get_pdb_file(pdb_id, filetype='pdb', compression=False):
 #     return remove_at_sign(out['representatives'])
 
 
-
 def find_results_gen(search_term, field='title'):
     '''
     Return a generator of the results returned by a search of
@@ -901,7 +810,6 @@ def find_results_gen(search_term, field='title'):
             yield result[field]
 
 
-
 def find_papers(search_term, max_results=10, **kwargs):
     '''
     Return an ordered list of the top papers returned by a keyword search of
@@ -940,6 +848,7 @@ def find_papers(search_term, max_results=10, **kwargs):
         all_papers += [item["title"] for item in pdb_info["citation"]]
     return remove_dupes(all_papers)
 
+
 # def find_authors(search_term, **kwargs):
 #     '''Return an ordered list of the top authors returned by a keyword search of
 #     the RCSB PDB
@@ -966,7 +875,6 @@ def find_papers(search_term, max_results=10, **kwargs):
 
 #     out : list of str
 
-
 #     Examples
 #     --------
 
@@ -1013,18 +921,13 @@ def find_papers(search_term, max_results=10, **kwargs):
 #     '''
 #     all_dates = parse_results_gen(search_term, field='deposition_date', **kwargs)
 #     return all_dates
-
-
-
-
-
-
 '''
 =================
 Helper Functions
 =================
 '''
 
+
 def to_dict(odict):
     '''Convert OrderedDict to dict
 
@@ -1049,6 +952,7 @@ def to_dict(odict):
     out = json.loads(json.dumps(odict))
     return out
 
+
 def remove_at_sign(kk):
     '''Remove the '@' character from the beginning of key names in a dict()
 
@@ -1072,6 +976,7 @@ def remove_at_sign(kk):
 
     return kk
 
+
 def remove_dupes(list_with_dupes):
     '''Remove duplicate entries from a list while preserving order
 
@@ -1101,9 +1006,13 @@ def remove_dupes(list_with_dupes):
     '''
     visited = set()
     visited_add = visited.add
-    out = [ entry for entry in list_with_dupes if not (entry in visited or visited_add(entry))]
+    out = [
+        entry for entry in list_with_dupes
+        if not (entry in visited or visited_add(entry))
+    ]
     return out
 
+
 def walk_nested_dict(my_result, term, outputs=[], depth=0, maxdepth=25):
     '''
     For a nested dictionary that may itself comprise lists of
@@ -1139,26 +1048,32 @@ def walk_nested_dict(my_result, term, outputs=[], depth=0, maxdepth=25):
     '''
 
     if depth > maxdepth:
-        warnings.warn('Maximum recursion depth exceeded. Returned None for the search results,'+
-                      ' try increasing the maxdepth keyword argument.')
+        warnings.warn(
+            'Maximum recursion depth exceeded. Returned None for the search results,'
+            + ' try increasing the maxdepth keyword argument.')
         return None
 
-
     depth = depth + 1
 
-    if type(my_result)==dict:
+    if type(my_result) == dict:
         if term in my_result.keys():
             outputs.append(my_result[term])
 
         else:
             new_results = list(my_result.values())
-            walk_nested_dict(new_results, term, outputs=outputs,
-                            depth=depth, maxdepth=maxdepth)
+            walk_nested_dict(new_results,
+                             term,
+                             outputs=outputs,
+                             depth=depth,
+                             maxdepth=maxdepth)
 
-    elif type(my_result)==list:
+    elif type(my_result) == list:
         for item in my_result:
-            walk_nested_dict(item, term, outputs=outputs,
-                            depth=depth, maxdepth=maxdepth)
+            walk_nested_dict(item,
+                             term,
+                             outputs=outputs,
+                             depth=depth,
+                             maxdepth=maxdepth)
 
     else:
         pass
